#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

FLAVORS_TEMPLATE_NAME = 'horizon/common/_data_table_view.html'
FLAVORS_INDEX_URL = 'horizon:admin:flavors:index'
FLAVORS_CREATE_URL = 'horizon:admin:flavors:create'
FLAVORS_CREATE_VIEW_TEMPLATE = 'admin/flavors/create.html'
FLAVORS_UPDATE_URL = 'horizon:admin:flavors:update'
FLAVORS_UPDATE_VIEW_TEMPLATE = 'admin/flavors/update.html'
